@@ -12,48 +12,51 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-// .NAME vtkFixedPointVolumeRayCastMapper - A fixed point mapper for volumes
-// .SECTION Description
-// This is a software ray caster for rendering volumes in vtkImageData.
-// It works with all input data types and up to four components. It performs
-// composite or MIP rendering, and can be intermixed with geometric data.
-// Space leaping is used to speed up the rendering process. In addition,
-// calculation are performed in 15 bit fixed point precision. This mapper
-// is threaded, and will interleave scan lines across processors.
-//
-// WARNING: This ray caster may not produce consistent results when
-// the number of threads exceeds 1. The class warns if the number of
-// threads > 1. The differences may be subtle. Applications should decide
-// if the trade-off in performance is worth the lack of consistency.
-//
-// This mapper is a good replacement for vtkVolumeRayCastMapper EXCEPT:
-//   - it does not do isosurface ray casting
-//   - it does only interpolate before classify compositing
-//   - it does only maximum scalar value MIP
-//
-// The vtkVolumeRayCastMapper CANNOT be used in these instances when a
-// vtkFixedPointVolumeRayCastMapper can be used:
-//   - if the data is not unsigned char or unsigned short
-//   - if the data has more than one component
-//
-// This mapper handles all data type from unsigned char through double.
-// However, some of the internal calcultions are performed in float and
-// therefore even the full float range may cause problems for this mapper
-// (both in scalar data values and in spacing between samples).
-//
-// Space leaping is performed by creating a sub-sampled volume. 4x4x4
-// cells in the original volume are represented by a min, max, and
-// combined gradient and flag value. The min max volume has three
-// unsigned shorts per 4x4x4 group of cells from the original volume -
-// one reprenting the minimum scalar index (the scalar value adjusted
-// to fit in the 15 bit range), the maximum scalar index, and a
-// third unsigned short which is both the maximum gradient opacity in
-// the neighborhood (an unsigned char) and the flag that is filled
-// in for the current lookup tables to indicate whether this region
-// can be skipped.
-
-// .SECTION see also
-// vtkVolumeMapper
+/**
+ * @class   vtkFixedPointVolumeRayCastMapper
+ * @brief   A fixed point mapper for volumes
+ *
+ * This is a software ray caster for rendering volumes in vtkImageData.
+ * It works with all input data types and up to four components. It performs
+ * composite or MIP rendering, and can be intermixed with geometric data.
+ * Space leaping is used to speed up the rendering process. In addition,
+ * calculation are performed in 15 bit fixed point precision. This mapper
+ * is threaded, and will interleave scan lines across processors.
+ *
+ * WARNING: This ray caster may not produce consistent results when
+ * the number of threads exceeds 1. The class warns if the number of
+ * threads > 1. The differences may be subtle. Applications should decide
+ * if the trade-off in performance is worth the lack of consistency.
+ *
+ * This mapper is a good replacement for vtkVolumeRayCastMapper EXCEPT:
+ *   - it does not do isosurface ray casting
+ *   - it does only interpolate before classify compositing
+ *   - it does only maximum scalar value MIP
+ *
+ * The vtkVolumeRayCastMapper CANNOT be used in these instances when a
+ * vtkFixedPointVolumeRayCastMapper can be used:
+ *   - if the data is not unsigned char or unsigned short
+ *   - if the data has more than one component
+ *
+ * This mapper handles all data type from unsigned char through double.
+ * However, some of the internal calcultions are performed in float and
+ * therefore even the full float range may cause problems for this mapper
+ * (both in scalar data values and in spacing between samples).
+ *
+ * Space leaping is performed by creating a sub-sampled volume. 4x4x4
+ * cells in the original volume are represented by a min, max, and
+ * combined gradient and flag value. The min max volume has three
+ * unsigned shorts per 4x4x4 group of cells from the original volume -
+ * one reprenting the minimum scalar index (the scalar value adjusted
+ * to fit in the 15 bit range), the maximum scalar index, and a
+ * third unsigned short which is both the maximum gradient opacity in
+ * the neighborhood (an unsigned char) and the flag that is filled
+ * in for the current lookup tables to indicate whether this region
+ * can be skipped.
+ *
+ * @sa
+ * vtkVolumeMapper
+*/
 
 #ifndef vtkFixedPointVolumeRayCastMapper_h
 #define vtkFixedPointVolumeRayCastMapper_h
@@ -89,110 +92,138 @@ class vtkRayCastImageDisplayHelper;
 class vtkFixedPointRayCastImage;
 class vtkDataArray;
 
-//BTX
 // Forward declaration needed for use by friend declaration below.
 VTK_THREAD_RETURN_TYPE FixedPointVolumeRayCastMapper_CastRays( void *arg );
 VTK_THREAD_RETURN_TYPE vtkFPVRCMSwitchOnDataType( void *arg );
-//ETX
 
 class VTKRENDERINGVOLUME_EXPORT vtkFixedPointVolumeRayCastMapper : public vtkVolumeMapper
 {
 public:
   static vtkFixedPointVolumeRayCastMapper *New();
   vtkTypeMacro(vtkFixedPointVolumeRayCastMapper,vtkVolumeMapper);
-  void PrintSelf( ostream& os, vtkIndent indent );
+  void PrintSelf( ostream& os, vtkIndent indent ) VTK_OVERRIDE;
 
-  // Description:
-  // Set/Get the distance between samples used for rendering
-  // when AutoAdjustSampleDistances is off, or when this mapper
-  // has more than 1 second allocated to it for rendering.
+  //@{
+  /**
+   * Set/Get the distance between samples used for rendering
+   * when AutoAdjustSampleDistances is off, or when this mapper
+   * has more than 1 second allocated to it for rendering.
+   */
   vtkSetMacro( SampleDistance, float );
   vtkGetMacro( SampleDistance, float );
+  //@}
 
-  // Description:
-  // Set/Get the distance between samples when interactive rendering is happening.
-  // In this case, interactive is defined as this volume mapper having less than 1
-  // second allocated for rendering. When AutoAdjustSampleDistance is On, and the
-  // allocated render time is less than 1 second, then this InteractiveSampleDistance
-  // will be used instead of the SampleDistance above.
+  //@{
+  /**
+   * Set/Get the distance between samples when interactive rendering is happening.
+   * In this case, interactive is defined as this volume mapper having less than 1
+   * second allocated for rendering. When AutoAdjustSampleDistance is On, and the
+   * allocated render time is less than 1 second, then this InteractiveSampleDistance
+   * will be used instead of the SampleDistance above.
+   */
   vtkSetMacro( InteractiveSampleDistance, float );
   vtkGetMacro( InteractiveSampleDistance, float );
+  //@}
 
-  // Description:
-  // Sampling distance in the XY image dimensions. Default value of 1 meaning
-  // 1 ray cast per pixel. If set to 0.5, 4 rays will be cast per pixel. If
-  // set to 2.0, 1 ray will be cast for every 4 (2 by 2) pixels. This value
-  // will be adjusted to meet a desired frame rate when AutoAdjustSampleDistances
-  // is on.
+  //@{
+  /**
+   * Sampling distance in the XY image dimensions. Default value of 1 meaning
+   * 1 ray cast per pixel. If set to 0.5, 4 rays will be cast per pixel. If
+   * set to 2.0, 1 ray will be cast for every 4 (2 by 2) pixels. This value
+   * will be adjusted to meet a desired frame rate when AutoAdjustSampleDistances
+   * is on.
+   */
   vtkSetClampMacro( ImageSampleDistance, float, 0.1f, 100.0f );
   vtkGetMacro( ImageSampleDistance, float );
+  //@}
 
-  // Description:
-  // This is the minimum image sample distance allow when the image
-  // sample distance is being automatically adjusted.
+  //@{
+  /**
+   * This is the minimum image sample distance allow when the image
+   * sample distance is being automatically adjusted.
+   */
   vtkSetClampMacro( MinimumImageSampleDistance, float, 0.1f, 100.0f );
   vtkGetMacro( MinimumImageSampleDistance, float );
+  //@}
 
-  // Description:
-  // This is the maximum image sample distance allow when the image
-  // sample distance is being automatically adjusted.
+  //@{
+  /**
+   * This is the maximum image sample distance allow when the image
+   * sample distance is being automatically adjusted.
+   */
   vtkSetClampMacro( MaximumImageSampleDistance, float, 0.1f, 100.0f );
   vtkGetMacro( MaximumImageSampleDistance, float );
+  //@}
 
-  // Description:
-  // If AutoAdjustSampleDistances is on, the the ImageSampleDistance
-  // and the SampleDistance will be varied to achieve the allocated
-  // render time of this prop (controlled by the desired update rate
-  // and any culling in use). If this is an interactive render (more
-  // than 1 frame per second) the SampleDistance will be increased,
-  // otherwise it will not be altered (a binary decision, as opposed
-  // to the ImageSampleDistance which will vary continuously).
+  //@{
+  /**
+   * If AutoAdjustSampleDistances is on, the the ImageSampleDistance
+   * and the SampleDistance will be varied to achieve the allocated
+   * render time of this prop (controlled by the desired update rate
+   * and any culling in use). If this is an interactive render (more
+   * than 1 frame per second) the SampleDistance will be increased,
+   * otherwise it will not be altered (a binary decision, as opposed
+   * to the ImageSampleDistance which will vary continuously).
+   */
   vtkSetClampMacro( AutoAdjustSampleDistances, int, 0, 1 );
   vtkGetMacro( AutoAdjustSampleDistances, int );
   vtkBooleanMacro( AutoAdjustSampleDistances, int );
+  //@}
 
-  // Description:
-  // Automatically compute the sample distance from the data spacing.  When
-  // the number of voxels is 8, the sample distance will be roughly 1/200
-  // the average voxel size. The distance will grow proportionally to
-  // numVoxels^(1/3) until it reaches 1/2 average voxel size when number of
-  // voxels is 1E6. Note that ScalarOpacityUnitDistance is still taken into
-  // account and if different than 1, will effect the sample distance.
+  //@{
+  /**
+   * Automatically compute the sample distance from the data spacing.  When
+   * the number of voxels is 8, the sample distance will be roughly 1/200
+   * the average voxel size. The distance will grow proportionally to
+   * numVoxels^(1/3) until it reaches 1/2 average voxel size when number of
+   * voxels is 1E6. Note that ScalarOpacityUnitDistance is still taken into
+   * account and if different than 1, will effect the sample distance.
+   */
   vtkSetClampMacro( LockSampleDistanceToInputSpacing, int, 0, 1 );
   vtkGetMacro( LockSampleDistanceToInputSpacing, int );
   vtkBooleanMacro( LockSampleDistanceToInputSpacing, int );
+  //@}
 
-  // Description:
-  // Set/Get the number of threads to use. This by default is equal to
-  // the number of available processors detected.
-  // WARNING: If number of threads > 1, results may not be consistent.
+  //@{
+  /**
+   * Set/Get the number of threads to use. This by default is equal to
+   * the number of available processors detected.
+   * WARNING: If number of threads > 1, results may not be consistent.
+   */
   void SetNumberOfThreads( int num );
   int GetNumberOfThreads();
+  //@}
 
-  // Description:
-  // If IntermixIntersectingGeometry is turned on, the zbuffer will be
-  // captured and used to limit the traversal of the rays.
+  //@{
+  /**
+   * If IntermixIntersectingGeometry is turned on, the zbuffer will be
+   * captured and used to limit the traversal of the rays.
+   */
   vtkSetClampMacro( IntermixIntersectingGeometry, int, 0, 1 );
   vtkGetMacro( IntermixIntersectingGeometry, int );
   vtkBooleanMacro( IntermixIntersectingGeometry, int );
+  //@}
 
-  // Description:
-  // What is the image sample distance required to achieve the desired time?
-  // A version of this method is provided that does not require the volume
-  // argument since if you are using an LODProp3D you may not know this information.
-  // If you use this version you must be certain that the ray cast mapper is
-  // only used for one volume (and not shared among multiple volumes)
+  //@{
+  /**
+   * What is the image sample distance required to achieve the desired time?
+   * A version of this method is provided that does not require the volume
+   * argument since if you are using an LODProp3D you may not know this information.
+   * If you use this version you must be certain that the ray cast mapper is
+   * only used for one volume (and not shared among multiple volumes)
+   */
   float ComputeRequiredImageSampleDistance( float desiredTime,
                                             vtkRenderer *ren );
   float ComputeRequiredImageSampleDistance( float desiredTime,
                                             vtkRenderer *ren,
                                             vtkVolume *vol );
+  //@}
 
-//BTX
-  // Description:
-  // WARNING: INTERNAL METHOD - NOT INTENDED FOR GENERAL USE
-  // Initialize rendering for this volume.
-  void Render( vtkRenderer *, vtkVolume * );
+  /**
+   * WARNING: INTERNAL METHOD - NOT INTENDED FOR GENERAL USE
+   * Initialize rendering for this volume.
+   */
+  void Render( vtkRenderer *, vtkVolume * ) VTK_OVERRIDE;
 
   unsigned int ToFixedPointPosition( float val );
   void ToFixedPointPosition( float in[3], unsigned int out[3] );
@@ -223,8 +254,6 @@ public:
     unsigned char  color[4] );
   int CheckIfCropped( unsigned int pos[3] );
 
-//ETX
-
   vtkGetObjectMacro( RenderWindow, vtkRenderWindow );
   vtkGetObjectMacro( MIPHelper, vtkFixedPointVolumeRayCastMIPHelper );
   vtkGetObjectMacro( CompositeHelper, vtkFixedPointVolumeRayCastCompositeHelper );
@@ -259,12 +288,15 @@ public:
 
   int ShouldUseNearestNeighborInterpolation( vtkVolume *vol );
 
-  // Description:
-  // Set / Get the underlying image object. One will be automatically
-  // created - only need to set it when using from an AMR mapper which
-  // renders multiple times into the same image.
+  //@{
+  /**
+   * Set / Get the underlying image object. One will be automatically
+   * created - only need to set it when using from an AMR mapper which
+   * renders multiple times into the same image.
+   */
   void SetRayCastImage( vtkFixedPointRayCastImage * );
   vtkGetObjectMacro( RayCastImage, vtkFixedPointRayCastImage  );
+  //@}
 
   int PerImageInitialization( vtkRenderer *, vtkVolume *, int,
                               double *, double *, int * );
@@ -280,11 +312,12 @@ public:
                             double viewDirection[3],
                             double viewUp[3] );
 
-  // Description:
-  // Get an estimate of the rendering time for a given volume / renderer.
-  // Only valid if this mapper has been used to render that volume for
-  // that renderer previously. Estimate is good when the viewing parameters
-  // have not changed much since that last render.
+  /**
+   * Get an estimate of the rendering time for a given volume / renderer.
+   * Only valid if this mapper has been used to render that volume for
+   * that renderer previously. Estimate is good when the viewing parameters
+   * have not changed much since that last render.
+   */
   float GetEstimatedRenderTime( vtkRenderer *ren,
                                 vtkVolume   *vol )
     { return this->RetrieveRenderTime( ren, vol ); }
@@ -292,22 +325,25 @@ public:
     { return this->RetrieveRenderTime( ren ); }
 
 
-  // Description:
-  // Set/Get the window / level applied to the final color.
-  // This allows brightness / contrast adjustments on the
-  // final image.
-  // window is the width of the window.
-  // level is the center of the window.
-  // Initial window value is 1.0
-  // Initial level value is 0.5
-  // window cannot be null but can be negative, this way
-  // values will be reversed.
-  // |window| can be larger than 1.0
-  // level can be any real value.
+  //@{
+  /**
+   * Set/Get the window / level applied to the final color.
+   * This allows brightness / contrast adjustments on the
+   * final image.
+   * window is the width of the window.
+   * level is the center of the window.
+   * Initial window value is 1.0
+   * Initial level value is 0.5
+   * window cannot be null but can be negative, this way
+   * values will be reversed.
+   * |window| can be larger than 1.0
+   * level can be any real value.
+   */
   vtkSetMacro( FinalColorWindow, float );
   vtkGetMacro( FinalColorWindow, float );
   vtkSetMacro( FinalColorLevel,  float );
   vtkGetMacro( FinalColorLevel,  float );
+  //@}
 
 
   // Here to be used by the mapper to tell the helper
@@ -315,16 +351,17 @@ public:
   // minimum intensity blending
   vtkGetMacro( FlipMIPComparison, int );
 
-  // Description:
-  // WARNING: INTERNAL METHOD - NOT INTENDED FOR GENERAL USE
-  // Release any graphics resources that are being consumed by this mapper.
-  // The parameter window could be used to determine which graphic
-  // resources to release.
-  virtual void ReleaseGraphicsResources(vtkWindow *);
+  /**
+   * WARNING: INTERNAL METHOD - NOT INTENDED FOR GENERAL USE
+   * Release any graphics resources that are being consumed by this mapper.
+   * The parameter window could be used to determine which graphic
+   * resources to release.
+   */
+  void ReleaseGraphicsResources(vtkWindow *) VTK_OVERRIDE;
 
 protected:
   vtkFixedPointVolumeRayCastMapper();
-  ~vtkFixedPointVolumeRayCastMapper();
+  ~vtkFixedPointVolumeRayCastMapper() VTK_OVERRIDE;
 
   // The helper class that displays the image
   vtkRayCastImageDisplayHelper *ImageDisplayHelper;
@@ -511,8 +548,8 @@ protected:
   void ApplyFinalColorWindowLevel();
 
 private:
-  vtkFixedPointVolumeRayCastMapper(const vtkFixedPointVolumeRayCastMapper&);  // Not implemented.
-  void operator=(const vtkFixedPointVolumeRayCastMapper&);  // Not implemented.
+  vtkFixedPointVolumeRayCastMapper(const vtkFixedPointVolumeRayCastMapper&) VTK_DELETE_FUNCTION;
+  void operator=(const vtkFixedPointVolumeRayCastMapper&) VTK_DELETE_FUNCTION;
 
   bool ThreadWarning;
 };
@@ -556,29 +593,29 @@ inline void vtkFixedPointVolumeRayCastMapper::ToFixedPointDirection( float in[3]
 inline void vtkFixedPointVolumeRayCastMapper::FixedPointIncrement( unsigned int position[3], unsigned int increment[3] )
 {
   if ( increment[0]&0x80000000 )
-    {
+  {
     position[0] += (increment[0]&0x7fffffff);
-    }
+  }
   else
-    {
+  {
     position[0] -= increment[0];
-    }
+  }
   if ( increment[1]&0x80000000 )
-    {
+  {
     position[1] += (increment[1]&0x7fffffff);
-    }
+  }
   else
-    {
+  {
     position[1] -= increment[1];
-    }
+  }
   if ( increment[2]&0x80000000 )
-    {
+  {
     position[2] += (increment[2]&0x7fffffff);
-    }
+  }
   else
-    {
+  {
     position[2] -= increment[2];
-    }
+  }
 }
 
 
@@ -627,20 +664,20 @@ inline int vtkFixedPointVolumeRayCastMapper::CheckMIPMinMaxVolumeFlag( unsigned
       mmpos[0] ) + static_cast<vtkIdType>(c);
 
   if ( (*(this->MinMaxVolume + 3*offset + 2)&0x00ff) )
-    {
+  {
     if (flip)
-      {
-      return ( *(this->MinMaxVolume + 3*offset) < maxIdx );
-      }
-    else
-      {
-      return ( *(this->MinMaxVolume + 3*offset + 1) > maxIdx );
-      }
-    }
-  else
     {
-    return 0;
+      return ( *(this->MinMaxVolume + 3*offset) < maxIdx );
     }
+    else
+    {
+      return ( *(this->MinMaxVolume + 3*offset + 1) > maxIdx );
+    }
+  }
+  else
+  {
+    return 0;
+  }
 }
 
 inline void vtkFixedPointVolumeRayCastMapper::LookupColorUC( unsigned short *colorTable,
@@ -666,7 +703,7 @@ inline void vtkFixedPointVolumeRayCastMapper::LookupDependentColorUC( unsigned s
 {
   unsigned short alpha;
   switch ( components )
-    {
+  {
     case 2:
       alpha = scalarOpacityTable[index[1]];
       color[0] = static_cast<unsigned char>
@@ -684,7 +721,7 @@ inline void vtkFixedPointVolumeRayCastMapper::LookupDependentColorUC( unsigned s
       color[2] = static_cast<unsigned char>((index[2]*alpha + 0x7fff)>>VTKKW_FP_SHIFT );
       color[3] = static_cast<unsigned char>(alpha>>(VTKKW_FP_SHIFT - 8));
       break;
-    }
+  }
 }
 
 
@@ -698,13 +735,13 @@ inline void vtkFixedPointVolumeRayCastMapper::LookupAndCombineIndependentColorsU
   unsigned int tmp[4] = {0,0,0,0};
 
   for ( int i = 0; i < components; i++ )
-    {
+  {
     unsigned short alpha = static_cast<unsigned short>(static_cast<float>(scalarOpacityTable[i][index[i]])*weights[i]);
     tmp[0] += static_cast<unsigned char>(((colorTable[i][3*index[i]  ])*alpha + 0x7fff)>>(2*VTKKW_FP_SHIFT - 8));
     tmp[1] += static_cast<unsigned char>(((colorTable[i][3*index[i]+1])*alpha + 0x7fff)>>(2*VTKKW_FP_SHIFT - 8));
     tmp[2] += static_cast<unsigned char>(((colorTable[i][3*index[i]+2])*alpha + 0x7fff)>>(2*VTKKW_FP_SHIFT - 8));
     tmp[3] += static_cast<unsigned char>(alpha>>(VTKKW_FP_SHIFT - 8));
-    }
+  }
 
   color[0] = static_cast<unsigned char>((tmp[0]>255)?(255):(tmp[0]));
   color[1] = static_cast<unsigned char>((tmp[1]>255)?(255):(tmp[1]));
@@ -718,41 +755,41 @@ inline int vtkFixedPointVolumeRayCastMapper::CheckIfCropped( unsigned int pos[3]
   int idx;
 
   if ( pos[2] < this->FixedPointCroppingRegionPlanes[4] )
-    {
+  {
     idx = 0;
-    }
+  }
   else if ( pos[2] > this->FixedPointCroppingRegionPlanes[5] )
-    {
+  {
     idx = 18;
-    }
+  }
   else
-    {
+  {
     idx = 9;
-    }
+  }
 
   if ( pos[1] >= this->FixedPointCroppingRegionPlanes[2] )
-    {
+  {
     if ( pos[1] > this->FixedPointCroppingRegionPlanes[3] )
-      {
+    {
       idx += 6;
-      }
-    else
-      {
-      idx += 3;
-      }
     }
+    else
+    {
+      idx += 3;
+    }
+  }
 
   if ( pos[0] >= this->FixedPointCroppingRegionPlanes[0] )
-    {
+  {
     if ( pos[0] > this->FixedPointCroppingRegionPlanes[1] )
-      {
+    {
       idx += 2;
-      }
-    else
-      {
-      idx += 1;
-      }
     }
+    else
+    {
+      idx += 1;
+    }
+  }
 
   return !(static_cast<unsigned int>(this->CroppingRegionFlags)
            &this->CroppingRegionMask[idx]);
