@@ -4,12 +4,12 @@
 package vtk;
 import vtk.*;
 
-public class vtkTemporalSnapToTimeStep extends vtkAlgorithm
+public class vtkTemporalSnapToTimeStep extends vtkPassInputTypeAlgorithm
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
