@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkTransformFilter extends vtkPointSetAlgorithm
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -29,7 +29,7 @@ public class vtkTransformFilter extends vtkPointSetAlgorithm
 
     if (temp == 0) return null;
     return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native int FillInputPortInformation_5(int id0,vtkInformation id1);
   public int FillInputPortInformation(int id0,vtkInformation id1)
